==> owlapi-parsers-3.4.1-sources.jar: org/coode/owlapi/rdfxml/parser/GTPLiteralTripleHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.coode.owlapi.rdfxml.parser;

import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLLiteral;

/**
 * Author: Matthew Horridge<br>
 * The University of Manchester<br>
 * Bio-Health Informatics Group<br>
 * Date: 18/03/2011
 */
@SuppressWarnings("javadoc")
public class GTPLiteralTripleHandler extends AbstractLiteralTripleHandler {

    public GTPLiteralTripleHandler(OWLRDFConsumer consumer) {
        super(consumer);
    }

    @Override
    public void handleTriple(IRI subject, IRI predicate, OWLLiteral object) {
        if(isStrict()) {

        }
        else {
            if(isAnnotationPropertyLax(predicate)) {

            }
            else {
                
            }
        }
    }

    @Override
    public boolean canHandleStreaming(IRI subject, IRI predicate, OWLLiteral object) {
        if (isStrict()) {
            return false;
        }
        else {
            return isAnnotationPropertyLax(predicate);
        }
    }

    @Override
    public boolean canHandle(IRI subject, IRI predicate, OWLLiteral object) {
        if (isAnnotationPropertyStrict(predicate)) {
            return true;
        }
        else if (isDataPropertyStrict(predicate)) {
            return true;
        }
        else {
            return false;
        }
    }


}

==> owlapi-parsers-3.5.0-sources.jar: org/coode/owlapi/rdfxml/parser/GTPLiteralTripleHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.coode.owlapi.rdfxml.parser;

import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLLiteral;

/**
 * @author Matthew Horridge, The University of Manchester, Bio-Health Informatics
 *         Group, Date: 18/03/2011
 */
public class GTPLiteralTripleHandler extends AbstractLiteralTripleHandler {

    /**
     * @param consumer
     *        consumer
     */
    public GTPLiteralTripleHandler(OWLRDFConsumer consumer) {
        super(consumer);
    }

    @Override
    public void handleTriple(IRI subject, IRI predicate, OWLLiteral object) {
        if (isStrict()) {} else {
            if (isAnnotationPropertyLax(predicate)) {} else {}
        }
    }

    @Override
    public boolean canHandleStreaming(IRI subject, IRI predicate,
            OWLLiteral object) {
        if (isStrict()) {
            return false;
        }
        return isAnnotationPropertyLax(predicate);
    }

    @Override
    public boolean canHandle(IRI subject, IRI predicate, OWLLiteral object) {
        return isAnnotationPropertyStrict(predicate)
                || isDataPropertyStrict(predicate);
    }
}
